# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from authentik_client.models.user_self_groups import UserSelfGroups
from authentik_client.models.user_type_enum import UserTypeEnum
from typing import Optional, Set
from typing_extensions import Self

class UserSelf(BaseModel):
    """
    User Serializer for information a user can retrieve about themselves
    """ # noqa: E501
    pk: StrictInt
    username: Annotated[str, Field(strict=True, max_length=150)] = Field(description="Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.")
    name: StrictStr = Field(description="User's display name.")
    is_active: StrictBool = Field(description="Designates whether this user should be treated as active. Unselect this instead of deleting accounts.")
    is_superuser: StrictBool
    groups: List[UserSelfGroups]
    email: Optional[Annotated[str, Field(strict=True, max_length=254)]] = None
    avatar: StrictStr = Field(description="User's avatar, either a http/https URL or a data URI")
    uid: StrictStr
    settings: Dict[str, Any] = Field(description="Get user settings with brand and group settings applied")
    type: Optional[UserTypeEnum] = None
    system_permissions: List[StrictStr] = Field(description="Get all system permissions assigned to the user")
    __properties: ClassVar[List[str]] = ["pk", "username", "name", "is_active", "is_superuser", "groups", "email", "avatar", "uid", "settings", "type", "system_permissions"]

    @field_validator('username')
    def username_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[\w.@+-]+$", value):
            raise ValueError(r"must validate the regular expression /^[\w.@+-]+$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UserSelf from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "pk",
            "is_active",
            "is_superuser",
            "groups",
            "avatar",
            "uid",
            "settings",
            "system_permissions",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in groups (list)
        _items = []
        if self.groups:
            for _item_groups in self.groups:
                if _item_groups:
                    _items.append(_item_groups.to_dict())
            _dict['groups'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UserSelf from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "pk": obj.get("pk"),
            "username": obj.get("username"),
            "name": obj.get("name"),
            "is_active": obj.get("is_active"),
            "is_superuser": obj.get("is_superuser"),
            "groups": [UserSelfGroups.from_dict(_item) for _item in obj["groups"]] if obj.get("groups") is not None else None,
            "email": obj.get("email"),
            "avatar": obj.get("avatar"),
            "uid": obj.get("uid"),
            "settings": obj.get("settings"),
            "type": obj.get("type"),
            "system_permissions": obj.get("system_permissions")
        })
        return _obj





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.authenticator_validation_challenge import AuthenticatorValidationChallenge

class TestAuthenticatorValidationChallenge(unittest.TestCase):
    """AuthenticatorValidationChallenge unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AuthenticatorValidationChallenge:
        """Test AuthenticatorValidationChallenge
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AuthenticatorValidationChallenge`
        """
        model = AuthenticatorValidationChallenge()
        if include_optional:
            return AuthenticatorValidationChallenge(
                flow_info = authentik_client.models.contextual_flow_info.ContextualFlowInfo(
                    title = '', 
                    background = '', 
                    cancel_url = '', 
                    layout = 'stacked', ),
                component = 'ak-stage-authenticator-validate',
                response_errors = {
                    'key' : [
                        authentik_client.models.error_detail.ErrorDetail(
                            string = '', 
                            code = '', )
                        ]
                    },
                pending_user = '',
                pending_user_avatar = '',
                device_challenges = [
                    authentik_client.models.device_challenge.DeviceChallenge(
                        device_class = '', 
                        device_uid = '', 
                        challenge = {
                            'key' : null
                            }, 
                        last_used = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                configuration_stages = [
                    authentik_client.models.selectable_stage.SelectableStage(
                        pk = '', 
                        name = '', 
                        verbose_name = '', 
                        meta_model_name = '', )
                    ]
            )
        else:
            return AuthenticatorValidationChallenge(
                pending_user = '',
                pending_user_avatar = '',
                device_challenges = [
                    authentik_client.models.device_challenge.DeviceChallenge(
                        device_class = '', 
                        device_uid = '', 
                        challenge = {
                            'key' : null
                            }, 
                        last_used = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                configuration_stages = [
                    authentik_client.models.selectable_stage.SelectableStage(
                        pk = '', 
                        name = '', 
                        verbose_name = '', 
                        meta_model_name = '', )
                    ],
        )
        """

    def testAuthenticatorValidationChallenge(self):
        """Test AuthenticatorValidationChallenge"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.policy_binding import PolicyBinding

class TestPolicyBinding(unittest.TestCase):
    """PolicyBinding unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PolicyBinding:
        """Test PolicyBinding
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PolicyBinding`
        """
        model = PolicyBinding()
        if include_optional:
            return PolicyBinding(
                pk = '',
                policy = '',
                group = '',
                user = 56,
                policy_obj = authentik_client.models.policy.Policy(
                    pk = '', 
                    name = '', 
                    execution_logging = True, 
                    component = '', 
                    verbose_name = '', 
                    verbose_name_plural = '', 
                    meta_model_name = '', 
                    bound_to = 56, ),
                group_obj = authentik_client.models.group.Group(
                    pk = '', 
                    num_pk = 56, 
                    name = '', 
                    is_superuser = True, 
                    parent = '', 
                    parent_name = '', 
                    users = [
                        56
                        ], 
                    users_obj = [
                        authentik_client.models.group_member.GroupMember(
                            pk = 56, 
                            username = 'A', 
                            name = '', 
                            is_active = True, 
                            last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            email = '', 
                            attributes = {
                                'key' : null
                                }, 
                            uid = '', )
                        ], 
                    attributes = {
                        'key' : null
                        }, 
                    roles = [
                        ''
                        ], 
                    roles_obj = [
                        authentik_client.models.role.Role(
                            pk = '', 
                            name = '', )
                        ], ),
                user_obj = authentik_client.models.user.User(
                    pk = 56, 
                    username = '', 
                    name = '', 
                    is_active = True, 
                    last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    date_joined = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    is_superuser = True, 
                    groups = [
                        ''
                        ], 
                    groups_obj = [
                        authentik_client.models.user_group.UserGroup(
                            pk = '', 
                            num_pk = 56, 
                            name = '', 
                            is_superuser = True, 
                            parent = '', 
                            parent_name = '', 
                            attributes = {
                                'key' : null
                                }, )
                        ], 
                    email = '', 
                    avatar = '', 
                    attributes = {
                        'key' : null
                        }, 
                    uid = '', 
                    path = '', 
                    type = 'internal', 
                    uuid = '', 
                    password_change_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                target = '',
                negate = True,
                enabled = True,
                order = -2147483648,
                timeout = 0,
                failure_result = True
            )
        else:
            return PolicyBinding(
                pk = '',
                policy_obj = authentik_client.models.policy.Policy(
                    pk = '', 
                    name = '', 
                    execution_logging = True, 
                    component = '', 
                    verbose_name = '', 
                    verbose_name_plural = '', 
                    meta_model_name = '', 
                    bound_to = 56, ),
                group_obj = authentik_client.models.group.Group(
                    pk = '', 
                    num_pk = 56, 
                    name = '', 
                    is_superuser = True, 
                    parent = '', 
                    parent_name = '', 
                    users = [
                        56
                        ], 
                    users_obj = [
                        authentik_client.models.group_member.GroupMember(
                            pk = 56, 
                            username = 'A', 
                            name = '', 
                            is_active = True, 
                            last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            email = '', 
                            attributes = {
                                'key' : null
                                }, 
                            uid = '', )
                        ], 
                    attributes = {
                        'key' : null
                        }, 
                    roles = [
                        ''
                        ], 
                    roles_obj = [
                        authentik_client.models.role.Role(
                            pk = '', 
                            name = '', )
                        ], ),
                user_obj = authentik_client.models.user.User(
                    pk = 56, 
                    username = '', 
                    name = '', 
                    is_active = True, 
                    last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    date_joined = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    is_superuser = True, 
                    groups = [
                        ''
                        ], 
                    groups_obj = [
                        authentik_client.models.user_group.UserGroup(
                            pk = '', 
                            num_pk = 56, 
                            name = '', 
                            is_superuser = True, 
                            parent = '', 
                            parent_name = '', 
                            attributes = {
                                'key' : null
                                }, )
                        ], 
                    email = '', 
                    avatar = '', 
                    attributes = {
                        'key' : null
                        }, 
                    uid = '', 
                    path = '', 
                    type = 'internal', 
                    uuid = '', 
                    password_change_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                target = '',
                order = -2147483648,
        )
        """

    def testPolicyBinding(self):
        """Test PolicyBinding"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.proxy_provider import ProxyProvider

class TestProxyProvider(unittest.TestCase):
    """ProxyProvider unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProxyProvider:
        """Test ProxyProvider
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProxyProvider`
        """
        model = ProxyProvider()
        if include_optional:
            return ProxyProvider(
                pk = 56,
                name = '',
                authentication_flow = '',
                authorization_flow = '',
                invalidation_flow = '',
                property_mappings = [
                    ''
                    ],
                component = '',
                assigned_application_slug = '',
                assigned_application_name = '',
                assigned_backchannel_application_slug = '',
                assigned_backchannel_application_name = '',
                verbose_name = '',
                verbose_name_plural = '',
                meta_model_name = '',
                client_id = '',
                internal_host = '',
                external_host = '',
                internal_host_ssl_validation = True,
                certificate = '',
                skip_path_regex = '',
                basic_auth_enabled = True,
                basic_auth_password_attribute = '',
                basic_auth_user_attribute = '',
                mode = 'proxy',
                intercept_header_auth = True,
                redirect_uris = [
                    authentik_client.models.redirect_uri.RedirectURI(
                        matching_mode = 'strict', 
                        url = '', )
                    ],
                cookie_domain = '',
                jwt_federation_sources = [
                    ''
                    ],
                jwt_federation_providers = [
                    56
                    ],
                access_token_validity = '',
                refresh_token_validity = '',
                outpost_set = [
                    ''
                    ]
            )
        else:
            return ProxyProvider(
                pk = 56,
                name = '',
                authorization_flow = '',
                invalidation_flow = '',
                component = '',
                assigned_application_slug = '',
                assigned_application_name = '',
                assigned_backchannel_application_slug = '',
                assigned_backchannel_application_name = '',
                verbose_name = '',
                verbose_name_plural = '',
                meta_model_name = '',
                client_id = '',
                external_host = '',
                redirect_uris = [
                    authentik_client.models.redirect_uri.RedirectURI(
                        matching_mode = 'strict', 
                        url = '', )
                    ],
                outpost_set = [
                    ''
                    ],
        )
        """

    def testProxyProvider(self):
        """Test ProxyProvider"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from authentik_client.models.intent_enum import IntentEnum
from typing import Optional, Set
from typing_extensions import Self

class TokenRequest(BaseModel):
    """
    Token Serializer
    """ # noqa: E501
    managed: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.")
    identifier: Annotated[str, Field(min_length=1, strict=True, max_length=255)]
    intent: Optional[IntentEnum] = None
    user: Optional[StrictInt] = None
    description: Optional[StrictStr] = None
    expires: Optional[datetime] = None
    expiring: Optional[StrictBool] = None
    __properties: ClassVar[List[str]] = ["managed", "identifier", "intent", "user", "description", "expires", "expiring"]

    @field_validator('identifier')
    def identifier_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[-a-zA-Z0-9_]+$", value):
            raise ValueError(r"must validate the regular expression /^[-a-zA-Z0-9_]+$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TokenRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if managed (nullable) is None
        # and model_fields_set contains the field
        if self.managed is None and "managed" in self.model_fields_set:
            _dict['managed'] = None

        # set to None if expires (nullable) is None
        # and model_fields_set contains the field
        if self.expires is None and "expires" in self.model_fields_set:
            _dict['expires'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TokenRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "managed": obj.get("managed"),
            "identifier": obj.get("identifier"),
            "intent": obj.get("intent"),
            "user": obj.get("user"),
            "description": obj.get("description"),
            "expires": obj.get("expires"),
            "expiring": obj.get("expiring")
        })
        return _obj





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.paginated_provider_list import PaginatedProviderList

class TestPaginatedProviderList(unittest.TestCase):
    """PaginatedProviderList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedProviderList:
        """Test PaginatedProviderList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedProviderList`
        """
        model = PaginatedProviderList()
        if include_optional:
            return PaginatedProviderList(
                pagination = authentik_client.models.pagination.Pagination(
                    next = 1.337, 
                    previous = 1.337, 
                    count = 1.337, 
                    current = 1.337, 
                    total_pages = 1.337, 
                    start_index = 1.337, 
                    end_index = 1.337, ),
                results = [
                    authentik_client.models.provider.Provider(
                        pk = 56, 
                        name = '', 
                        authentication_flow = '', 
                        authorization_flow = '', 
                        invalidation_flow = '', 
                        property_mappings = [
                            ''
                            ], 
                        component = '', 
                        assigned_application_slug = '', 
                        assigned_application_name = '', 
                        assigned_backchannel_application_slug = '', 
                        assigned_backchannel_application_name = '', 
                        verbose_name = '', 
                        verbose_name_plural = '', 
                        meta_model_name = '', )
                    ]
            )
        else:
            return PaginatedProviderList(
                pagination = authentik_client.models.pagination.Pagination(
                    next = 1.337, 
                    previous = 1.337, 
                    count = 1.337, 
                    current = 1.337, 
                    total_pages = 1.337, 
                    start_index = 1.337, 
                    end_index = 1.337, ),
                results = [
                    authentik_client.models.provider.Provider(
                        pk = 56, 
                        name = '', 
                        authentication_flow = '', 
                        authorization_flow = '', 
                        invalidation_flow = '', 
                        property_mappings = [
                            ''
                            ], 
                        component = '', 
                        assigned_application_slug = '', 
                        assigned_application_name = '', 
                        assigned_backchannel_application_slug = '', 
                        assigned_backchannel_application_name = '', 
                        verbose_name = '', 
                        verbose_name_plural = '', 
                        meta_model_name = '', )
                    ],
        )
        """

    def testPaginatedProviderList(self):
        """Test PaginatedProviderList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.managed_api import ManagedApi


class TestManagedApi(unittest.TestCase):
    """ManagedApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ManagedApi()

    def tearDown(self) -> None:
        pass

    def test_managed_blueprints_apply_create(self) -> None:
        """Test case for managed_blueprints_apply_create

        """
        pass

    def test_managed_blueprints_available_list(self) -> None:
        """Test case for managed_blueprints_available_list

        """
        pass

    def test_managed_blueprints_create(self) -> None:
        """Test case for managed_blueprints_create

        """
        pass

    def test_managed_blueprints_destroy(self) -> None:
        """Test case for managed_blueprints_destroy

        """
        pass

    def test_managed_blueprints_list(self) -> None:
        """Test case for managed_blueprints_list

        """
        pass

    def test_managed_blueprints_partial_update(self) -> None:
        """Test case for managed_blueprints_partial_update

        """
        pass

    def test_managed_blueprints_retrieve(self) -> None:
        """Test case for managed_blueprints_retrieve

        """
        pass

    def test_managed_blueprints_update(self) -> None:
        """Test case for managed_blueprints_update

        """
        pass

    def test_managed_blueprints_used_by_list(self) -> None:
        """Test case for managed_blueprints_used_by_list

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.providers_api import ProvidersApi


class TestProvidersApi(unittest.TestCase):
    """ProvidersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ProvidersApi()

    def tearDown(self) -> None:
        pass

    def test_providers_all_destroy(self) -> None:
        """Test case for providers_all_destroy

        """
        pass

    def test_providers_all_list(self) -> None:
        """Test case for providers_all_list

        """
        pass

    def test_providers_all_retrieve(self) -> None:
        """Test case for providers_all_retrieve

        """
        pass

    def test_providers_all_types_list(self) -> None:
        """Test case for providers_all_types_list

        """
        pass

    def test_providers_all_used_by_list(self) -> None:
        """Test case for providers_all_used_by_list

        """
        pass

    def test_providers_google_workspace_create(self) -> None:
        """Test case for providers_google_workspace_create

        """
        pass

    def test_providers_google_workspace_destroy(self) -> None:
        """Test case for providers_google_workspace_destroy

        """
        pass

    def test_providers_google_workspace_groups_create(self) -> None:
        """Test case for providers_google_workspace_groups_create

        """
        pass

    def test_providers_google_workspace_groups_destroy(self) -> None:
        """Test case for providers_google_workspace_groups_destroy

        """
        pass

    def test_providers_google_workspace_groups_list(self) -> None:
        """Test case for providers_google_workspace_groups_list

        """
        pass

    def test_providers_google_workspace_groups_retrieve(self) -> None:
        """Test case for providers_google_workspace_groups_retrieve

        """
        pass

    def test_providers_google_workspace_groups_used_by_list(self) -> None:
        """Test case for providers_google_workspace_groups_used_by_list

        """
        pass

    def test_providers_google_workspace_list(self) -> None:
        """Test case for providers_google_workspace_list

        """
        pass

    def test_providers_google_workspace_partial_update(self) -> None:
        """Test case for providers_google_workspace_partial_update

        """
        pass

    def test_providers_google_workspace_retrieve(self) -> None:
        """Test case for providers_google_workspace_retrieve

        """
        pass

    def test_providers_google_workspace_sync_object_create(self) -> None:
        """Test case for providers_google_workspace_sync_object_create

        """
        pass

    def test_providers_google_workspace_sync_status_retrieve(self) -> None:
        """Test case for providers_google_workspace_sync_status_retrieve

        """
        pass

    def test_providers_google_workspace_update(self) -> None:
        """Test case for providers_google_workspace_update

        """
        pass

    def test_providers_google_workspace_used_by_list(self) -> None:
        """Test case for providers_google_workspace_used_by_list

        """
        pass

    def test_providers_google_workspace_users_create(self) -> None:
        """Test case for providers_google_workspace_users_create

        """
        pass

    def test_providers_google_workspace_users_destroy(self) -> None:
        """Test case for providers_google_workspace_users_destroy

        """
        pass

    def test_providers_google_workspace_users_list(self) -> None:
        """Test case for providers_google_workspace_users_list

        """
        pass

    def test_providers_google_workspace_users_retrieve(self) -> None:
        """Test case for providers_google_workspace_users_retrieve

        """
        pass

    def test_providers_google_workspace_users_used_by_list(self) -> None:
        """Test case for providers_google_workspace_users_used_by_list

        """
        pass

    def test_providers_ldap_create(self) -> None:
        """Test case for providers_ldap_create

        """
        pass

    def test_providers_ldap_destroy(self) -> None:
        """Test case for providers_ldap_destroy

        """
        pass

    def test_providers_ldap_list(self) -> None:
        """Test case for providers_ldap_list

        """
        pass

    def test_providers_ldap_partial_update(self) -> None:
        """Test case for providers_ldap_partial_update

        """
        pass

    def test_providers_ldap_retrieve(self) -> None:
        """Test case for providers_ldap_retrieve

        """
        pass

    def test_providers_ldap_update(self) -> None:
        """Test case for providers_ldap_update

        """
        pass

    def test_providers_ldap_used_by_list(self) -> None:
        """Test case for providers_ldap_used_by_list

        """
        pass

    def test_providers_microsoft_entra_create(self) -> None:
        """Test case for providers_microsoft_entra_create

        """
        pass

    def test_providers_microsoft_entra_destroy(self) -> None:
        """Test case for providers_microsoft_entra_destroy

        """
        pass

    def test_providers_microsoft_entra_groups_create(self) -> None:
        """Test case for providers_microsoft_entra_groups_create

        """
        pass

    def test_providers_microsoft_entra_groups_destroy(self) -> None:
        """Test case for providers_microsoft_entra_groups_destroy

        """
        pass

    def test_providers_microsoft_entra_groups_list(self) -> None:
        """Test case for providers_microsoft_entra_groups_list

        """
        pass

    def test_providers_microsoft_entra_groups_retrieve(self) -> None:
        """Test case for providers_microsoft_entra_groups_retrieve

        """
        pass

    def test_providers_microsoft_entra_groups_used_by_list(self) -> None:
        """Test case for providers_microsoft_entra_groups_used_by_list

        """
        pass

    def test_providers_microsoft_entra_list(self) -> None:
        """Test case for providers_microsoft_entra_list

        """
        pass

    def test_providers_microsoft_entra_partial_update(self) -> None:
        """Test case for providers_microsoft_entra_partial_update

        """
        pass

    def test_providers_microsoft_entra_retrieve(self) -> None:
        """Test case for providers_microsoft_entra_retrieve

        """
        pass

    def test_providers_microsoft_entra_sync_object_create(self) -> None:
        """Test case for providers_microsoft_entra_sync_object_create

        """
        pass

    def test_providers_microsoft_entra_sync_status_retrieve(self) -> None:
        """Test case for providers_microsoft_entra_sync_status_retrieve

        """
        pass

    def test_providers_microsoft_entra_update(self) -> None:
        """Test case for providers_microsoft_entra_update

        """
        pass

    def test_providers_microsoft_entra_used_by_list(self) -> None:
        """Test case for providers_microsoft_entra_used_by_list

        """
        pass

    def test_providers_microsoft_entra_users_create(self) -> None:
        """Test case for providers_microsoft_entra_users_create

        """
        pass

    def test_providers_microsoft_entra_users_destroy(self) -> None:
        """Test case for providers_microsoft_entra_users_destroy

        """
        pass

    def test_providers_microsoft_entra_users_list(self) -> None:
        """Test case for providers_microsoft_entra_users_list

        """
        pass

    def test_providers_microsoft_entra_users_retrieve(self) -> None:
        """Test case for providers_microsoft_entra_users_retrieve

        """
        pass

    def test_providers_microsoft_entra_users_used_by_list(self) -> None:
        """Test case for providers_microsoft_entra_users_used_by_list

        """
        pass

    def test_providers_oauth2_create(self) -> None:
        """Test case for providers_oauth2_create

        """
        pass

    def test_providers_oauth2_destroy(self) -> None:
        """Test case for providers_oauth2_destroy

        """
        pass

    def test_providers_oauth2_list(self) -> None:
        """Test case for providers_oauth2_list

        """
        pass

    def test_providers_oauth2_partial_update(self) -> None:
        """Test case for providers_oauth2_partial_update

        """
        pass

    def test_providers_oauth2_preview_user_retrieve(self) -> None:
        """Test case for providers_oauth2_preview_user_retrieve

        """
        pass

    def test_providers_oauth2_retrieve(self) -> None:
        """Test case for providers_oauth2_retrieve

        """
        pass

    def test_providers_oauth2_setup_urls_retrieve(self) -> None:
        """Test case for providers_oauth2_setup_urls_retrieve

        """
        pass

    def test_providers_oauth2_update(self) -> None:
        """Test case for providers_oauth2_update

        """
        pass

    def test_providers_oauth2_used_by_list(self) -> None:
        """Test case for providers_oauth2_used_by_list

        """
        pass

    def test_providers_proxy_create(self) -> None:
        """Test case for providers_proxy_create

        """
        pass

    def test_providers_proxy_destroy(self) -> None:
        """Test case for providers_proxy_destroy

        """
        pass

    def test_providers_proxy_list(self) -> None:
        """Test case for providers_proxy_list

        """
        pass

    def test_providers_proxy_partial_update(self) -> None:
        """Test case for providers_proxy_partial_update

        """
        pass

    def test_providers_proxy_retrieve(self) -> None:
        """Test case for providers_proxy_retrieve

        """
        pass

    def test_providers_proxy_update(self) -> None:
        """Test case for providers_proxy_update

        """
        pass

    def test_providers_proxy_used_by_list(self) -> None:
        """Test case for providers_proxy_used_by_list

        """
        pass

    def test_providers_rac_create(self) -> None:
        """Test case for providers_rac_create

        """
        pass

    def test_providers_rac_destroy(self) -> None:
        """Test case for providers_rac_destroy

        """
        pass

    def test_providers_rac_list(self) -> None:
        """Test case for providers_rac_list

        """
        pass

    def test_providers_rac_partial_update(self) -> None:
        """Test case for providers_rac_partial_update

        """
        pass

    def test_providers_rac_retrieve(self) -> None:
        """Test case for providers_rac_retrieve

        """
        pass

    def test_providers_rac_update(self) -> None:
        """Test case for providers_rac_update

        """
        pass

    def test_providers_rac_used_by_list(self) -> None:
        """Test case for providers_rac_used_by_list

        """
        pass

    def test_providers_radius_create(self) -> None:
        """Test case for providers_radius_create

        """
        pass

    def test_providers_radius_destroy(self) -> None:
        """Test case for providers_radius_destroy

        """
        pass

    def test_providers_radius_list(self) -> None:
        """Test case for providers_radius_list

        """
        pass

    def test_providers_radius_partial_update(self) -> None:
        """Test case for providers_radius_partial_update

        """
        pass

    def test_providers_radius_retrieve(self) -> None:
        """Test case for providers_radius_retrieve

        """
        pass

    def test_providers_radius_update(self) -> None:
        """Test case for providers_radius_update

        """
        pass

    def test_providers_radius_used_by_list(self) -> None:
        """Test case for providers_radius_used_by_list

        """
        pass

    def test_providers_saml_create(self) -> None:
        """Test case for providers_saml_create

        """
        pass

    def test_providers_saml_destroy(self) -> None:
        """Test case for providers_saml_destroy

        """
        pass

    def test_providers_saml_import_metadata_create(self) -> None:
        """Test case for providers_saml_import_metadata_create

        """
        pass

    def test_providers_saml_list(self) -> None:
        """Test case for providers_saml_list

        """
        pass

    def test_providers_saml_metadata_retrieve(self) -> None:
        """Test case for providers_saml_metadata_retrieve

        """
        pass

    def test_providers_saml_partial_update(self) -> None:
        """Test case for providers_saml_partial_update

        """
        pass

    def test_providers_saml_preview_user_retrieve(self) -> None:
        """Test case for providers_saml_preview_user_retrieve

        """
        pass

    def test_providers_saml_retrieve(self) -> None:
        """Test case for providers_saml_retrieve

        """
        pass

    def test_providers_saml_update(self) -> None:
        """Test case for providers_saml_update

        """
        pass

    def test_providers_saml_used_by_list(self) -> None:
        """Test case for providers_saml_used_by_list

        """
        pass

    def test_providers_scim_create(self) -> None:
        """Test case for providers_scim_create

        """
        pass

    def test_providers_scim_destroy(self) -> None:
        """Test case for providers_scim_destroy

        """
        pass

    def test_providers_scim_groups_create(self) -> None:
        """Test case for providers_scim_groups_create

        """
        pass

    def test_providers_scim_groups_destroy(self) -> None:
        """Test case for providers_scim_groups_destroy

        """
        pass

    def test_providers_scim_groups_list(self) -> None:
        """Test case for providers_scim_groups_list

        """
        pass

    def test_providers_scim_groups_retrieve(self) -> None:
        """Test case for providers_scim_groups_retrieve

        """
        pass

    def test_providers_scim_groups_used_by_list(self) -> None:
        """Test case for providers_scim_groups_used_by_list

        """
        pass

    def test_providers_scim_list(self) -> None:
        """Test case for providers_scim_list

        """
        pass

    def test_providers_scim_partial_update(self) -> None:
        """Test case for providers_scim_partial_update

        """
        pass

    def test_providers_scim_retrieve(self) -> None:
        """Test case for providers_scim_retrieve

        """
        pass

    def test_providers_scim_sync_object_create(self) -> None:
        """Test case for providers_scim_sync_object_create

        """
        pass

    def test_providers_scim_sync_status_retrieve(self) -> None:
        """Test case for providers_scim_sync_status_retrieve

        """
        pass

    def test_providers_scim_update(self) -> None:
        """Test case for providers_scim_update

        """
        pass

    def test_providers_scim_used_by_list(self) -> None:
        """Test case for providers_scim_used_by_list

        """
        pass

    def test_providers_scim_users_create(self) -> None:
        """Test case for providers_scim_users_create

        """
        pass

    def test_providers_scim_users_destroy(self) -> None:
        """Test case for providers_scim_users_destroy

        """
        pass

    def test_providers_scim_users_list(self) -> None:
        """Test case for providers_scim_users_list

        """
        pass

    def test_providers_scim_users_retrieve(self) -> None:
        """Test case for providers_scim_users_retrieve

        """
        pass

    def test_providers_scim_users_used_by_list(self) -> None:
        """Test case for providers_scim_users_used_by_list

        """
        pass

    def test_providers_ssf_create(self) -> None:
        """Test case for providers_ssf_create

        """
        pass

    def test_providers_ssf_destroy(self) -> None:
        """Test case for providers_ssf_destroy

        """
        pass

    def test_providers_ssf_list(self) -> None:
        """Test case for providers_ssf_list

        """
        pass

    def test_providers_ssf_partial_update(self) -> None:
        """Test case for providers_ssf_partial_update

        """
        pass

    def test_providers_ssf_retrieve(self) -> None:
        """Test case for providers_ssf_retrieve

        """
        pass

    def test_providers_ssf_update(self) -> None:
        """Test case for providers_ssf_update

        """
        pass

    def test_providers_ssf_used_by_list(self) -> None:
        """Test case for providers_ssf_used_by_list

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.authenticator_sms_challenge import AuthenticatorSMSChallenge

class TestAuthenticatorSMSChallenge(unittest.TestCase):
    """AuthenticatorSMSChallenge unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AuthenticatorSMSChallenge:
        """Test AuthenticatorSMSChallenge
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AuthenticatorSMSChallenge`
        """
        model = AuthenticatorSMSChallenge()
        if include_optional:
            return AuthenticatorSMSChallenge(
                flow_info = authentik_client.models.contextual_flow_info.ContextualFlowInfo(
                    title = '', 
                    background = '', 
                    cancel_url = '', 
                    layout = 'stacked', ),
                component = 'ak-stage-authenticator-sms',
                response_errors = {
                    'key' : [
                        authentik_client.models.error_detail.ErrorDetail(
                            string = '', 
                            code = '', )
                        ]
                    },
                pending_user = '',
                pending_user_avatar = '',
                phone_number_required = True
            )
        else:
            return AuthenticatorSMSChallenge(
                pending_user = '',
                pending_user_avatar = '',
        )
        """

    def testAuthenticatorSMSChallenge(self):
        """Test AuthenticatorSMSChallenge"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.paginated_authenticated_session_list import PaginatedAuthenticatedSessionList

class TestPaginatedAuthenticatedSessionList(unittest.TestCase):
    """PaginatedAuthenticatedSessionList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedAuthenticatedSessionList:
        """Test PaginatedAuthenticatedSessionList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedAuthenticatedSessionList`
        """
        model = PaginatedAuthenticatedSessionList()
        if include_optional:
            return PaginatedAuthenticatedSessionList(
                pagination = authentik_client.models.pagination.Pagination(
                    next = 1.337, 
                    previous = 1.337, 
                    count = 1.337, 
                    current = 1.337, 
                    total_pages = 1.337, 
                    start_index = 1.337, 
                    end_index = 1.337, ),
                results = [
                    authentik_client.models.authenticated_session.AuthenticatedSession(
                        uuid = '', 
                        current = True, 
                        user_agent = authentik_client.models.authenticated_session_user_agent.AuthenticatedSession_user_agent(
                            device = authentik_client.models.authenticated_session_user_agent_device.AuthenticatedSession_user_agent_device(
                                brand = '', 
                                family = '', 
                                model = '', ), 
                            os = authentik_client.models.authenticated_session_user_agent_os.AuthenticatedSession_user_agent_os(
                                family = '', 
                                major = '', 
                                minor = '', 
                                patch = '', 
                                patch_minor = '', ), 
                            user_agent = authentik_client.models.authenticated_session_user_agent_user_agent.AuthenticatedSession_user_agent_user_agent(
                                family = '', 
                                major = '', 
                                minor = '', 
                                patch = '', ), 
                            string = '', ), 
                        geo_ip = authentik_client.models.authenticated_session_geo_ip.AuthenticatedSession_geo_ip(
                            continent = '', 
                            country = '', 
                            lat = 1.337, 
                            long = 1.337, 
                            city = '', ), 
                        asn = authentik_client.models.authenticated_session_asn.AuthenticatedSession_asn(
                            asn = 56, 
                            as_org = '', 
                            network = '', ), 
                        user = 56, 
                        last_ip = '', 
                        last_user_agent = '', 
                        last_used = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return PaginatedAuthenticatedSessionList(
                pagination = authentik_client.models.pagination.Pagination(
                    next = 1.337, 
                    previous = 1.337, 
                    count = 1.337, 
                    current = 1.337, 
                    total_pages = 1.337, 
                    start_index = 1.337, 
                    end_index = 1.337, ),
                results = [
                    authentik_client.models.authenticated_session.AuthenticatedSession(
                        uuid = '', 
                        current = True, 
                        user_agent = authentik_client.models.authenticated_session_user_agent.AuthenticatedSession_user_agent(
                            device = authentik_client.models.authenticated_session_user_agent_device.AuthenticatedSession_user_agent_device(
                                brand = '', 
                                family = '', 
                                model = '', ), 
                            os = authentik_client.models.authenticated_session_user_agent_os.AuthenticatedSession_user_agent_os(
                                family = '', 
                                major = '', 
                                minor = '', 
                                patch = '', 
                                patch_minor = '', ), 
                            user_agent = authentik_client.models.authenticated_session_user_agent_user_agent.AuthenticatedSession_user_agent_user_agent(
                                family = '', 
                                major = '', 
                                minor = '', 
                                patch = '', ), 
                            string = '', ), 
                        geo_ip = authentik_client.models.authenticated_session_geo_ip.AuthenticatedSession_geo_ip(
                            continent = '', 
                            country = '', 
                            lat = 1.337, 
                            long = 1.337, 
                            city = '', ), 
                        asn = authentik_client.models.authenticated_session_asn.AuthenticatedSession_asn(
                            asn = 56, 
                            as_org = '', 
                            network = '', ), 
                        user = 56, 
                        last_ip = '', 
                        last_user_agent = '', 
                        last_used = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
        )
        """

    def testPaginatedAuthenticatedSessionList(self):
        """Test PaginatedAuthenticatedSessionList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LicenseSummaryStatusEnum(str, Enum):
    """
    LicenseSummaryStatusEnum
    """

    """
    allowed enum values
    """
    UNLICENSED = 'unlicensed'
    VALID = 'valid'
    EXPIRED = 'expired'
    EXPIRY_SOON = 'expiry_soon'
    LIMIT_EXCEEDED_ADMIN = 'limit_exceeded_admin'
    LIMIT_EXCEEDED_USER = 'limit_exceeded_user'
    READ_ONLY = 'read_only'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LicenseSummaryStatusEnum from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.patched_prompt_request import PatchedPromptRequest

class TestPatchedPromptRequest(unittest.TestCase):
    """PatchedPromptRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PatchedPromptRequest:
        """Test PatchedPromptRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PatchedPromptRequest`
        """
        model = PatchedPromptRequest()
        if include_optional:
            return PatchedPromptRequest(
                name = '0',
                field_key = '0',
                label = '0',
                type = 'text',
                required = True,
                placeholder = '',
                initial_value = '',
                order = -2147483648,
                promptstage_set = [
                    authentik_client.models.stage_request.StageRequest(
                        name = '0', 
                        flow_set = [
                            authentik_client.models.flow_set_request.FlowSetRequest(
                                name = '0', 
                                slug = 'z0', 
                                title = '0', 
                                designation = null, 
                                policy_engine_mode = 'all', 
                                compatibility_mode = True, 
                                layout = 'stacked', 
                                denied_action = null, )
                            ], )
                    ],
                sub_text = '',
                placeholder_expression = True,
                initial_value_expression = True
            )
        else:
            return PatchedPromptRequest(
        )
        """

    def testPatchedPromptRequest(self):
        """Test PatchedPromptRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.root_api import RootApi


class TestRootApi(unittest.TestCase):
    """RootApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RootApi()

    def tearDown(self) -> None:
        pass

    def test_root_config_retrieve(self) -> None:
        """Test case for root_config_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.system_task import SystemTask

class TestSystemTask(unittest.TestCase):
    """SystemTask unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SystemTask:
        """Test SystemTask
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SystemTask`
        """
        model = SystemTask()
        if include_optional:
            return SystemTask(
                uuid = '',
                name = '',
                full_name = '',
                uid = '',
                description = '',
                start_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                finish_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                duration = 1.337,
                status = 'unknown',
                messages = [
                    authentik_client.models.log_event.LogEvent(
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        log_level = 'critical', 
                        logger = '', 
                        event = '', 
                        attributes = {
                            'key' : null
                            }, )
                    ],
                expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                expiring = True
            )
        else:
            return SystemTask(
                uuid = '',
                name = '',
                full_name = '',
                description = '',
                start_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                finish_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                duration = 1.337,
                status = 'unknown',
                messages = [
                    authentik_client.models.log_event.LogEvent(
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        log_level = 'critical', 
                        logger = '', 
                        event = '', 
                        attributes = {
                            'key' : null
                            }, )
                    ],
        )
        """

    def testSystemTask(self):
        """Test SystemTask"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.patched_flow_stage_binding_request import PatchedFlowStageBindingRequest

class TestPatchedFlowStageBindingRequest(unittest.TestCase):
    """PatchedFlowStageBindingRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PatchedFlowStageBindingRequest:
        """Test PatchedFlowStageBindingRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PatchedFlowStageBindingRequest`
        """
        model = PatchedFlowStageBindingRequest()
        if include_optional:
            return PatchedFlowStageBindingRequest(
                target = '',
                stage = '',
                evaluate_on_plan = True,
                re_evaluate_policies = True,
                order = -2147483648,
                policy_engine_mode = 'all',
                invalid_response_action = 'retry'
            )
        else:
            return PatchedFlowStageBindingRequest(
        )
        """

    def testPatchedFlowStageBindingRequest(self):
        """Test PatchedFlowStageBindingRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.authenticators_api import AuthenticatorsApi


class TestAuthenticatorsApi(unittest.TestCase):
    """AuthenticatorsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AuthenticatorsApi()

    def tearDown(self) -> None:
        pass

    def test_authenticators_admin_all_list(self) -> None:
        """Test case for authenticators_admin_all_list

        """
        pass

    def test_authenticators_admin_duo_create(self) -> None:
        """Test case for authenticators_admin_duo_create

        """
        pass

    def test_authenticators_admin_duo_destroy(self) -> None:
        """Test case for authenticators_admin_duo_destroy

        """
        pass

    def test_authenticators_admin_duo_list(self) -> None:
        """Test case for authenticators_admin_duo_list

        """
        pass

    def test_authenticators_admin_duo_partial_update(self) -> None:
        """Test case for authenticators_admin_duo_partial_update

        """
        pass

    def test_authenticators_admin_duo_retrieve(self) -> None:
        """Test case for authenticators_admin_duo_retrieve

        """
        pass

    def test_authenticators_admin_duo_update(self) -> None:
        """Test case for authenticators_admin_duo_update

        """
        pass

    def test_authenticators_admin_email_create(self) -> None:
        """Test case for authenticators_admin_email_create

        """
        pass

    def test_authenticators_admin_email_destroy(self) -> None:
        """Test case for authenticators_admin_email_destroy

        """
        pass

    def test_authenticators_admin_email_list(self) -> None:
        """Test case for authenticators_admin_email_list

        """
        pass

    def test_authenticators_admin_email_partial_update(self) -> None:
        """Test case for authenticators_admin_email_partial_update

        """
        pass

    def test_authenticators_admin_email_retrieve(self) -> None:
        """Test case for authenticators_admin_email_retrieve

        """
        pass

    def test_authenticators_admin_email_update(self) -> None:
        """Test case for authenticators_admin_email_update

        """
        pass

    def test_authenticators_admin_endpoint_create(self) -> None:
        """Test case for authenticators_admin_endpoint_create

        """
        pass

    def test_authenticators_admin_endpoint_destroy(self) -> None:
        """Test case for authenticators_admin_endpoint_destroy

        """
        pass

    def test_authenticators_admin_endpoint_list(self) -> None:
        """Test case for authenticators_admin_endpoint_list

        """
        pass

    def test_authenticators_admin_endpoint_partial_update(self) -> None:
        """Test case for authenticators_admin_endpoint_partial_update

        """
        pass

    def test_authenticators_admin_endpoint_retrieve(self) -> None:
        """Test case for authenticators_admin_endpoint_retrieve

        """
        pass

    def test_authenticators_admin_endpoint_update(self) -> None:
        """Test case for authenticators_admin_endpoint_update

        """
        pass

    def test_authenticators_admin_sms_create(self) -> None:
        """Test case for authenticators_admin_sms_create

        """
        pass

    def test_authenticators_admin_sms_destroy(self) -> None:
        """Test case for authenticators_admin_sms_destroy

        """
        pass

    def test_authenticators_admin_sms_list(self) -> None:
        """Test case for authenticators_admin_sms_list

        """
        pass

    def test_authenticators_admin_sms_partial_update(self) -> None:
        """Test case for authenticators_admin_sms_partial_update

        """
        pass

    def test_authenticators_admin_sms_retrieve(self) -> None:
        """Test case for authenticators_admin_sms_retrieve

        """
        pass

    def test_authenticators_admin_sms_update(self) -> None:
        """Test case for authenticators_admin_sms_update

        """
        pass

    def test_authenticators_admin_static_create(self) -> None:
        """Test case for authenticators_admin_static_create

        """
        pass

    def test_authenticators_admin_static_destroy(self) -> None:
        """Test case for authenticators_admin_static_destroy

        """
        pass

    def test_authenticators_admin_static_list(self) -> None:
        """Test case for authenticators_admin_static_list

        """
        pass

    def test_authenticators_admin_static_partial_update(self) -> None:
        """Test case for authenticators_admin_static_partial_update

        """
        pass

    def test_authenticators_admin_static_retrieve(self) -> None:
        """Test case for authenticators_admin_static_retrieve

        """
        pass

    def test_authenticators_admin_static_update(self) -> None:
        """Test case for authenticators_admin_static_update

        """
        pass

    def test_authenticators_admin_totp_create(self) -> None:
        """Test case for authenticators_admin_totp_create

        """
        pass

    def test_authenticators_admin_totp_destroy(self) -> None:
        """Test case for authenticators_admin_totp_destroy

        """
        pass

    def test_authenticators_admin_totp_list(self) -> None:
        """Test case for authenticators_admin_totp_list

        """
        pass

    def test_authenticators_admin_totp_partial_update(self) -> None:
        """Test case for authenticators_admin_totp_partial_update

        """
        pass

    def test_authenticators_admin_totp_retrieve(self) -> None:
        """Test case for authenticators_admin_totp_retrieve

        """
        pass

    def test_authenticators_admin_totp_update(self) -> None:
        """Test case for authenticators_admin_totp_update

        """
        pass

    def test_authenticators_admin_webauthn_create(self) -> None:
        """Test case for authenticators_admin_webauthn_create

        """
        pass

    def test_authenticators_admin_webauthn_destroy(self) -> None:
        """Test case for authenticators_admin_webauthn_destroy

        """
        pass

    def test_authenticators_admin_webauthn_list(self) -> None:
        """Test case for authenticators_admin_webauthn_list

        """
        pass

    def test_authenticators_admin_webauthn_partial_update(self) -> None:
        """Test case for authenticators_admin_webauthn_partial_update

        """
        pass

    def test_authenticators_admin_webauthn_retrieve(self) -> None:
        """Test case for authenticators_admin_webauthn_retrieve

        """
        pass

    def test_authenticators_admin_webauthn_update(self) -> None:
        """Test case for authenticators_admin_webauthn_update

        """
        pass

    def test_authenticators_all_list(self) -> None:
        """Test case for authenticators_all_list

        """
        pass

    def test_authenticators_duo_destroy(self) -> None:
        """Test case for authenticators_duo_destroy

        """
        pass

    def test_authenticators_duo_list(self) -> None:
        """Test case for authenticators_duo_list

        """
        pass

    def test_authenticators_duo_partial_update(self) -> None:
        """Test case for authenticators_duo_partial_update

        """
        pass

    def test_authenticators_duo_retrieve(self) -> None:
        """Test case for authenticators_duo_retrieve

        """
        pass

    def test_authenticators_duo_update(self) -> None:
        """Test case for authenticators_duo_update

        """
        pass

    def test_authenticators_duo_used_by_list(self) -> None:
        """Test case for authenticators_duo_used_by_list

        """
        pass

    def test_authenticators_email_destroy(self) -> None:
        """Test case for authenticators_email_destroy

        """
        pass

    def test_authenticators_email_list(self) -> None:
        """Test case for authenticators_email_list

        """
        pass

    def test_authenticators_email_partial_update(self) -> None:
        """Test case for authenticators_email_partial_update

        """
        pass

    def test_authenticators_email_retrieve(self) -> None:
        """Test case for authenticators_email_retrieve

        """
        pass

    def test_authenticators_email_update(self) -> None:
        """Test case for authenticators_email_update

        """
        pass

    def test_authenticators_email_used_by_list(self) -> None:
        """Test case for authenticators_email_used_by_list

        """
        pass

    def test_authenticators_endpoint_list(self) -> None:
        """Test case for authenticators_endpoint_list

        """
        pass

    def test_authenticators_endpoint_retrieve(self) -> None:
        """Test case for authenticators_endpoint_retrieve

        """
        pass

    def test_authenticators_endpoint_used_by_list(self) -> None:
        """Test case for authenticators_endpoint_used_by_list

        """
        pass

    def test_authenticators_sms_destroy(self) -> None:
        """Test case for authenticators_sms_destroy

        """
        pass

    def test_authenticators_sms_list(self) -> None:
        """Test case for authenticators_sms_list

        """
        pass

    def test_authenticators_sms_partial_update(self) -> None:
        """Test case for authenticators_sms_partial_update

        """
        pass

    def test_authenticators_sms_retrieve(self) -> None:
        """Test case for authenticators_sms_retrieve

        """
        pass

    def test_authenticators_sms_update(self) -> None:
        """Test case for authenticators_sms_update

        """
        pass

    def test_authenticators_sms_used_by_list(self) -> None:
        """Test case for authenticators_sms_used_by_list

        """
        pass

    def test_authenticators_static_destroy(self) -> None:
        """Test case for authenticators_static_destroy

        """
        pass

    def test_authenticators_static_list(self) -> None:
        """Test case for authenticators_static_list

        """
        pass

    def test_authenticators_static_partial_update(self) -> None:
        """Test case for authenticators_static_partial_update

        """
        pass

    def test_authenticators_static_retrieve(self) -> None:
        """Test case for authenticators_static_retrieve

        """
        pass

    def test_authenticators_static_update(self) -> None:
        """Test case for authenticators_static_update

        """
        pass

    def test_authenticators_static_used_by_list(self) -> None:
        """Test case for authenticators_static_used_by_list

        """
        pass

    def test_authenticators_totp_destroy(self) -> None:
        """Test case for authenticators_totp_destroy

        """
        pass

    def test_authenticators_totp_list(self) -> None:
        """Test case for authenticators_totp_list

        """
        pass

    def test_authenticators_totp_partial_update(self) -> None:
        """Test case for authenticators_totp_partial_update

        """
        pass

    def test_authenticators_totp_retrieve(self) -> None:
        """Test case for authenticators_totp_retrieve

        """
        pass

    def test_authenticators_totp_update(self) -> None:
        """Test case for authenticators_totp_update

        """
        pass

    def test_authenticators_totp_used_by_list(self) -> None:
        """Test case for authenticators_totp_used_by_list

        """
        pass

    def test_authenticators_webauthn_destroy(self) -> None:
        """Test case for authenticators_webauthn_destroy

        """
        pass

    def test_authenticators_webauthn_list(self) -> None:
        """Test case for authenticators_webauthn_list

        """
        pass

    def test_authenticators_webauthn_partial_update(self) -> None:
        """Test case for authenticators_webauthn_partial_update

        """
        pass

    def test_authenticators_webauthn_retrieve(self) -> None:
        """Test case for authenticators_webauthn_retrieve

        """
        pass

    def test_authenticators_webauthn_update(self) -> None:
        """Test case for authenticators_webauthn_update

        """
        pass

    def test_authenticators_webauthn_used_by_list(self) -> None:
        """Test case for authenticators_webauthn_used_by_list

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.enterprise_api import EnterpriseApi


class TestEnterpriseApi(unittest.TestCase):
    """EnterpriseApi unit test stubs"""

    def setUp(self) -> None:
        self.api = EnterpriseApi()

    def tearDown(self) -> None:
        pass

    def test_enterprise_license_create(self) -> None:
        """Test case for enterprise_license_create

        """
        pass

    def test_enterprise_license_destroy(self) -> None:
        """Test case for enterprise_license_destroy

        """
        pass

    def test_enterprise_license_forecast_retrieve(self) -> None:
        """Test case for enterprise_license_forecast_retrieve

        """
        pass

    def test_enterprise_license_install_id_retrieve(self) -> None:
        """Test case for enterprise_license_install_id_retrieve

        """
        pass

    def test_enterprise_license_list(self) -> None:
        """Test case for enterprise_license_list

        """
        pass

    def test_enterprise_license_partial_update(self) -> None:
        """Test case for enterprise_license_partial_update

        """
        pass

    def test_enterprise_license_retrieve(self) -> None:
        """Test case for enterprise_license_retrieve

        """
        pass

    def test_enterprise_license_summary_retrieve(self) -> None:
        """Test case for enterprise_license_summary_retrieve

        """
        pass

    def test_enterprise_license_update(self) -> None:
        """Test case for enterprise_license_update

        """
        pass

    def test_enterprise_license_used_by_list(self) -> None:
        """Test case for enterprise_license_used_by_list

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class BrandRequest(BaseModel):
    """
    Brand Serializer
    """ # noqa: E501
    domain: Annotated[str, Field(min_length=1, strict=True)] = Field(description="Domain that activates this brand. Can be a superset, i.e. `a.b` for `aa.b` and `ba.b`")
    default: Optional[StrictBool] = None
    branding_title: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None
    branding_logo: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None
    branding_favicon: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None
    branding_custom_css: Optional[StrictStr] = None
    branding_default_flow_background: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None
    flow_authentication: Optional[StrictStr] = None
    flow_invalidation: Optional[StrictStr] = None
    flow_recovery: Optional[StrictStr] = None
    flow_unenrollment: Optional[StrictStr] = None
    flow_user_settings: Optional[StrictStr] = None
    flow_device_code: Optional[StrictStr] = None
    default_application: Optional[StrictStr] = Field(default=None, description="When set, external users will be redirected to this application after authenticating.")
    web_certificate: Optional[StrictStr] = Field(default=None, description="Web Certificate used by the authentik Core webserver.")
    client_certificates: Optional[List[StrictStr]] = Field(default=None, description="Certificates used for client authentication.")
    attributes: Optional[Any] = None
    __properties: ClassVar[List[str]] = ["domain", "default", "branding_title", "branding_logo", "branding_favicon", "branding_custom_css", "branding_default_flow_background", "flow_authentication", "flow_invalidation", "flow_recovery", "flow_unenrollment", "flow_user_settings", "flow_device_code", "default_application", "web_certificate", "client_certificates", "attributes"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BrandRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if flow_authentication (nullable) is None
        # and model_fields_set contains the field
        if self.flow_authentication is None and "flow_authentication" in self.model_fields_set:
            _dict['flow_authentication'] = None

        # set to None if flow_invalidation (nullable) is None
        # and model_fields_set contains the field
        if self.flow_invalidation is None and "flow_invalidation" in self.model_fields_set:
            _dict['flow_invalidation'] = None

        # set to None if flow_recovery (nullable) is None
        # and model_fields_set contains the field
        if self.flow_recovery is None and "flow_recovery" in self.model_fields_set:
            _dict['flow_recovery'] = None

        # set to None if flow_unenrollment (nullable) is None
        # and model_fields_set contains the field
        if self.flow_unenrollment is None and "flow_unenrollment" in self.model_fields_set:
            _dict['flow_unenrollment'] = None

        # set to None if flow_user_settings (nullable) is None
        # and model_fields_set contains the field
        if self.flow_user_settings is None and "flow_user_settings" in self.model_fields_set:
            _dict['flow_user_settings'] = None

        # set to None if flow_device_code (nullable) is None
        # and model_fields_set contains the field
        if self.flow_device_code is None and "flow_device_code" in self.model_fields_set:
            _dict['flow_device_code'] = None

        # set to None if default_application (nullable) is None
        # and model_fields_set contains the field
        if self.default_application is None and "default_application" in self.model_fields_set:
            _dict['default_application'] = None

        # set to None if web_certificate (nullable) is None
        # and model_fields_set contains the field
        if self.web_certificate is None and "web_certificate" in self.model_fields_set:
            _dict['web_certificate'] = None

        # set to None if attributes (nullable) is None
        # and model_fields_set contains the field
        if self.attributes is None and "attributes" in self.model_fields_set:
            _dict['attributes'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BrandRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "domain": obj.get("domain"),
            "default": obj.get("default"),
            "branding_title": obj.get("branding_title"),
            "branding_logo": obj.get("branding_logo"),
            "branding_favicon": obj.get("branding_favicon"),
            "branding_custom_css": obj.get("branding_custom_css"),
            "branding_default_flow_background": obj.get("branding_default_flow_background"),
            "flow_authentication": obj.get("flow_authentication"),
            "flow_invalidation": obj.get("flow_invalidation"),
            "flow_recovery": obj.get("flow_recovery"),
            "flow_unenrollment": obj.get("flow_unenrollment"),
            "flow_user_settings": obj.get("flow_user_settings"),
            "flow_device_code": obj.get("flow_device_code"),
            "default_application": obj.get("default_application"),
            "web_certificate": obj.get("web_certificate"),
            "client_certificates": obj.get("client_certificates"),
            "attributes": obj.get("attributes")
        })
        return _obj





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.flow_stage_binding import FlowStageBinding

class TestFlowStageBinding(unittest.TestCase):
    """FlowStageBinding unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlowStageBinding:
        """Test FlowStageBinding
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlowStageBinding`
        """
        model = FlowStageBinding()
        if include_optional:
            return FlowStageBinding(
                pk = '',
                policybindingmodel_ptr_id = '',
                target = '',
                stage = '',
                stage_obj = authentik_client.models.stage.Stage(
                    pk = '', 
                    name = '', 
                    component = '', 
                    verbose_name = '', 
                    verbose_name_plural = '', 
                    meta_model_name = '', 
                    flow_set = [
                        authentik_client.models.flow_set.FlowSet(
                            pk = '', 
                            policybindingmodel_ptr_id = '', 
                            name = '', 
                            slug = 'z', 
                            title = '', 
                            designation = null, 
                            background = '', 
                            policy_engine_mode = 'all', 
                            compatibility_mode = True, 
                            export_url = '', 
                            layout = 'stacked', 
                            denied_action = null, )
                        ], ),
                evaluate_on_plan = True,
                re_evaluate_policies = True,
                order = -2147483648,
                policy_engine_mode = 'all',
                invalid_response_action = 'retry'
            )
        else:
            return FlowStageBinding(
                pk = '',
                policybindingmodel_ptr_id = '',
                target = '',
                stage = '',
                stage_obj = authentik_client.models.stage.Stage(
                    pk = '', 
                    name = '', 
                    component = '', 
                    verbose_name = '', 
                    verbose_name_plural = '', 
                    meta_model_name = '', 
                    flow_set = [
                        authentik_client.models.flow_set.FlowSet(
                            pk = '', 
                            policybindingmodel_ptr_id = '', 
                            name = '', 
                            slug = 'z', 
                            title = '', 
                            designation = null, 
                            background = '', 
                            policy_engine_mode = 'all', 
                            compatibility_mode = True, 
                            export_url = '', 
                            layout = 'stacked', 
                            denied_action = null, )
                        ], ),
                order = -2147483648,
        )
        """

    def testFlowStageBinding(self):
        """Test FlowStageBinding"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.o_auth2_provider_request import OAuth2ProviderRequest

class TestOAuth2ProviderRequest(unittest.TestCase):
    """OAuth2ProviderRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OAuth2ProviderRequest:
        """Test OAuth2ProviderRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OAuth2ProviderRequest`
        """
        model = OAuth2ProviderRequest()
        if include_optional:
            return OAuth2ProviderRequest(
                name = '0',
                authentication_flow = '',
                authorization_flow = '',
                invalidation_flow = '',
                property_mappings = [
                    ''
                    ],
                client_type = 'confidential',
                client_id = '0',
                client_secret = '',
                access_code_validity = '0',
                access_token_validity = '0',
                refresh_token_validity = '0',
                include_claims_in_id_token = True,
                signing_key = '',
                encryption_key = '',
                redirect_uris = [
                    authentik_client.models.redirect_uri_request.RedirectURIRequest(
                        matching_mode = 'strict', 
                        url = '0', )
                    ],
                sub_mode = 'hashed_user_id',
                issuer_mode = 'global',
                jwt_federation_sources = [
                    ''
                    ],
                jwt_federation_providers = [
                    56
                    ]
            )
        else:
            return OAuth2ProviderRequest(
                name = '0',
                authorization_flow = '',
                invalidation_flow = '',
                redirect_uris = [
                    authentik_client.models.redirect_uri_request.RedirectURIRequest(
                        matching_mode = 'strict', 
                        url = '0', )
                    ],
        )
        """

    def testOAuth2ProviderRequest(self):
        """Test OAuth2ProviderRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.proxy_outpost_config import ProxyOutpostConfig

class TestProxyOutpostConfig(unittest.TestCase):
    """ProxyOutpostConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProxyOutpostConfig:
        """Test ProxyOutpostConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProxyOutpostConfig`
        """
        model = ProxyOutpostConfig()
        if include_optional:
            return ProxyOutpostConfig(
                pk = 56,
                name = '',
                internal_host = '',
                external_host = '',
                internal_host_ssl_validation = True,
                client_id = '',
                client_secret = '',
                oidc_configuration = authentik_client.models.open_id_connect_configuration.OpenIDConnectConfiguration(
                    issuer = '', 
                    authorization_endpoint = '', 
                    token_endpoint = '', 
                    userinfo_endpoint = '', 
                    end_session_endpoint = '', 
                    introspection_endpoint = '', 
                    jwks_uri = '', 
                    response_types_supported = [
                        ''
                        ], 
                    id_token_signing_alg_values_supported = [
                        ''
                        ], 
                    subject_types_supported = [
                        ''
                        ], 
                    token_endpoint_auth_methods_supported = [
                        ''
                        ], ),
                cookie_secret = '',
                certificate = '',
                skip_path_regex = '',
                basic_auth_enabled = True,
                basic_auth_password_attribute = '',
                basic_auth_user_attribute = '',
                mode = 'proxy',
                cookie_domain = '',
                access_token_validity = 1.337,
                intercept_header_auth = True,
                scopes_to_request = [
                    ''
                    ],
                assigned_application_slug = '',
                assigned_application_name = ''
            )
        else:
            return ProxyOutpostConfig(
                pk = 56,
                name = '',
                external_host = '',
                oidc_configuration = authentik_client.models.open_id_connect_configuration.OpenIDConnectConfiguration(
                    issuer = '', 
                    authorization_endpoint = '', 
                    token_endpoint = '', 
                    userinfo_endpoint = '', 
                    end_session_endpoint = '', 
                    introspection_endpoint = '', 
                    jwks_uri = '', 
                    response_types_supported = [
                        ''
                        ], 
                    id_token_signing_alg_values_supported = [
                        ''
                        ], 
                    subject_types_supported = [
                        ''
                        ], 
                    token_endpoint_auth_methods_supported = [
                        ''
                        ], ),
                access_token_validity = 1.337,
                scopes_to_request = [
                    ''
                    ],
                assigned_application_slug = '',
                assigned_application_name = '',
        )
        """

    def testProxyOutpostConfig(self):
        """Test ProxyOutpostConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.flow import Flow

class TestFlow(unittest.TestCase):
    """Flow unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Flow:
        """Test Flow
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Flow`
        """
        model = Flow()
        if include_optional:
            return Flow(
                pk = '',
                policybindingmodel_ptr_id = '',
                name = '',
                slug = 'z',
                title = '',
                designation = 'authentication',
                background = '',
                stages = [
                    ''
                    ],
                policies = [
                    ''
                    ],
                cache_count = 56,
                policy_engine_mode = 'all',
                compatibility_mode = True,
                export_url = '',
                layout = 'stacked',
                denied_action = 'message_continue',
                authentication = 'none'
            )
        else:
            return Flow(
                pk = '',
                policybindingmodel_ptr_id = '',
                name = '',
                slug = 'z',
                title = '',
                designation = 'authentication',
                background = '',
                stages = [
                    ''
                    ],
                policies = [
                    ''
                    ],
                cache_count = 56,
                export_url = '',
        )
        """

    def testFlow(self):
        """Test Flow"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.ssf_stream import SSFStream

class TestSSFStream(unittest.TestCase):
    """SSFStream unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SSFStream:
        """Test SSFStream
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SSFStream`
        """
        model = SSFStream()
        if include_optional:
            return SSFStream(
                pk = '',
                provider = 56,
                provider_obj = authentik_client.models.ssf_provider.SSFProvider(
                    pk = 56, 
                    name = '', 
                    component = '', 
                    verbose_name = '', 
                    verbose_name_plural = '', 
                    meta_model_name = '', 
                    signing_key = '', 
                    token_obj = null, 
                    oidc_auth_providers = [
                        56
                        ], 
                    ssf_url = '', 
                    event_retention = '', ),
                delivery_method = 'https://schemas.openid.net/secevent/risc/delivery-method/push',
                endpoint_url = '',
                events_requested = [
                    'https://schemas.openid.net/secevent/caep/event-type/session-revoked'
                    ],
                format = '',
                aud = [
                    ''
                    ],
                iss = ''
            )
        else:
            return SSFStream(
                pk = '',
                provider = 56,
                provider_obj = authentik_client.models.ssf_provider.SSFProvider(
                    pk = 56, 
                    name = '', 
                    component = '', 
                    verbose_name = '', 
                    verbose_name_plural = '', 
                    meta_model_name = '', 
                    signing_key = '', 
                    token_obj = null, 
                    oidc_auth_providers = [
                        56
                        ], 
                    ssf_url = '', 
                    event_retention = '', ),
                delivery_method = 'https://schemas.openid.net/secevent/risc/delivery-method/push',
                format = '',
                iss = '',
        )
        """

    def testSSFStream(self):
        """Test SSFStream"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class CertificateKeyPair(BaseModel):
    """
    CertificateKeyPair Serializer
    """ # noqa: E501
    pk: StrictStr
    name: StrictStr
    fingerprint_sha256: Optional[StrictStr] = Field(description="Get certificate Hash (SHA256)")
    fingerprint_sha1: Optional[StrictStr] = Field(description="Get certificate Hash (SHA1)")
    cert_expiry: Optional[datetime] = Field(description="Get certificate expiry")
    cert_subject: Optional[StrictStr] = Field(description="Get certificate subject as full rfc4514")
    private_key_available: StrictBool = Field(description="Show if this keypair has a private key configured or not")
    private_key_type: Optional[StrictStr] = Field(description="Get the private key's type, if set")
    certificate_download_url: StrictStr = Field(description="Get URL to download certificate")
    private_key_download_url: StrictStr = Field(description="Get URL to download private key")
    managed: Optional[StrictStr] = Field(description="Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.")
    __properties: ClassVar[List[str]] = ["pk", "name", "fingerprint_sha256", "fingerprint_sha1", "cert_expiry", "cert_subject", "private_key_available", "private_key_type", "certificate_download_url", "private_key_download_url", "managed"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CertificateKeyPair from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "pk",
            "fingerprint_sha256",
            "fingerprint_sha1",
            "cert_expiry",
            "cert_subject",
            "private_key_available",
            "private_key_type",
            "certificate_download_url",
            "private_key_download_url",
            "managed",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if fingerprint_sha256 (nullable) is None
        # and model_fields_set contains the field
        if self.fingerprint_sha256 is None and "fingerprint_sha256" in self.model_fields_set:
            _dict['fingerprint_sha256'] = None

        # set to None if fingerprint_sha1 (nullable) is None
        # and model_fields_set contains the field
        if self.fingerprint_sha1 is None and "fingerprint_sha1" in self.model_fields_set:
            _dict['fingerprint_sha1'] = None

        # set to None if cert_expiry (nullable) is None
        # and model_fields_set contains the field
        if self.cert_expiry is None and "cert_expiry" in self.model_fields_set:
            _dict['cert_expiry'] = None

        # set to None if cert_subject (nullable) is None
        # and model_fields_set contains the field
        if self.cert_subject is None and "cert_subject" in self.model_fields_set:
            _dict['cert_subject'] = None

        # set to None if private_key_type (nullable) is None
        # and model_fields_set contains the field
        if self.private_key_type is None and "private_key_type" in self.model_fields_set:
            _dict['private_key_type'] = None

        # set to None if managed (nullable) is None
        # and model_fields_set contains the field
        if self.managed is None and "managed" in self.model_fields_set:
            _dict['managed'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CertificateKeyPair from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "pk": obj.get("pk"),
            "name": obj.get("name"),
            "fingerprint_sha256": obj.get("fingerprint_sha256"),
            "fingerprint_sha1": obj.get("fingerprint_sha1"),
            "cert_expiry": obj.get("cert_expiry"),
            "cert_subject": obj.get("cert_subject"),
            "private_key_available": obj.get("private_key_available"),
            "private_key_type": obj.get("private_key_type"),
            "certificate_download_url": obj.get("certificate_download_url"),
            "private_key_download_url": obj.get("private_key_download_url"),
            "managed": obj.get("managed")
        })
        return _obj


